#!/bin/bash

#author				: hennes (jm@rapidrabbit.de)
#last changed		: 16-september-2007

#package			: Maelstrom
#homepage			: http://www.devolution.com/~slouken/Maelstrom/

# ----- credentials
softname="Maelstrom"
softversion="3.0.6"
srcurl="http://www.devolution.com/~slouken/Maelstrom/src/Maelstrom-3.0.6.tar.gz"
arch=i486
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc/$softname-$softversion
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
Maelstrom: Maelstrom (space shooter)
Maelstrom:
Maelstrom: You pilot your ship through the dreaded "Maelstrom" asteroid belt --
Maelstrom: suddenly your best friend thrusts towards you and fires, directly at
Maelstrom: your cockpit. You raise your shields just in time, and the battle is
Maelstrom: joined. The deadliest stretch of space known to mankind has just
Maelstrom: gotten deadlier. Everywhere massive asteroids jostle for a chance to
Maelstrom: crush your ship, and deadly shinobi fighter patrols pursue you across
Maelstrom: the asteroid belt. But the deadliest of them all is your sister ship,
Maelstrom: assigned to you on patrol.
Maelstrom:
EOF

# ----- extract source-archive
srcdir=$softname-$softversion
rm -rf $srcdir
if [ -f $softname-$softversion.tar.gz ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c $srcurl
fi
tar -zxvf $softname-$softversion.tar.gz
cd $srcdir

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- configure
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure	--prefix=$prefix

# ----- patch makefiles
sed -i 's|target=$(prefix)/games|target=$(DESTDIR)$(prefix)/share|' \
	./Makefile
sed -i 's|$(prefix)/games|$(prefix)/share|' \
	./Makefile
sed -i 's|$(prefix)/games|$(prefix)/share|' \
	./maclib/Makefile
sed -i 's|$(prefix)/games|$(prefix)/share|' \
	./netlogic/Makefile
sed -i 's|$(prefix)/games|$(prefix)/share|' \
	./screenlib/Makefile

# ----- make
make $numjobs

# ----- make install
make install DESTDIR=$dest
	
# ----- copy files
cp -a COPYING.* CREDITS Changelog INSTALL README.* $dest$prefix/doc/$softname-$softversion
cp ./Docs/* $dest$prefix/doc/$softname-$softversion
rm $dest$prefix/doc/$softname-$softversion/Makefile*

# ----- treat icon-file
cd $builddir
if [ -f $softname-48.png ]; then
   echo "looking for 48x48 icon .. found"
else
   echo "looking for 48x48 icon .. none found"
   wget -c http://rapidrabbit.de/jj/zenwalk/icons/$softname-48.png
fi
cp $softname-48.png $dest$prefix/share/icons/hicolor/48x48/apps/$softname.png

# ----- treat .desktop-file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Maelstrom
Comment=Space shooter
Exec=Maelstrom
Icon=Maelstrom
Terminal=false
Type=Application
Categories=Game;ActionGame;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null

# ----- packaging
chown -R root.root $dest
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << EOF > $package.dep
coreutils,cxxlibs,directfb,expat,fontconfig,freetype,gcc,gcc-g++,gdbm,libdrm,libjpeg,libpng,libtiff,mesa,ncurses,openssl,perl,sdl,sysfsutils,xorg,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
